@@ -1,18 +1,15 @@
 # __init__.py
 
 # version of ElectricKiwiApi for Python
-__version__ = "0.5.4"
+__version__ = "0.7.0"
 
 from electrickiwi_api.api import (
     ElectricKiwiEndpoint,
     ElectricKiwiApi
 )
 
-from apiclient import (
-    BasicAuthentication,
-    HeaderAuthentication,
-    NoAuthentication,
-    QueryParameterAuthentication,
+from electrickiwi_api.auth import (
+    AbstractAuth
 )
 
 # remove dev for production
